.. stickydesign documentation master file, created by
   sphinx-quickstart on Thu Dec 14 16:37:52 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to stickydesign's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   algorithms
   energymodels
   extending
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
